from django.conf import settings
from django.template import Library
from eem_py.url import signed_url

register = Library()


@register.simple_tag
def eem_image(source, **kwargs):
    return signed_url(
        settings.EEM_KEY,
        settings.EEM_HOST,
        source,
        debug=getattr(settings, 'EEM_DEBUG', False),
        **kwargs
    )



"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

import eem_django

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='eem_django',
    version=eem_django.__version__,
    description='Django app providing a template tag to create "eem" image manipulation URLs.',
    long_description=long_description,
    keywords='django image photo manipulate crop resize eem',

    url='https://github.com/eemagery',

    author='eemagery',
    # author_email='pypa-dev@googlegroups.com',

    license='MIT',

    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    install_requires=['eem_py'],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    # extras_require={
    #     'dev': ['check-manifest'],
    #     'test': ['coverage'],
    # },
)